==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/Dashboard.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * Dashboard
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class Dashboard extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<Dashboard> {

    /** Dashboard attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** uniqueId column */
        public static final String UNIQUEID ="uniqueId";
        /** title column */
        public static final String TITLE ="title";
        /** template column */
        public static final String TEMPLATE ="template";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("uniqueId");
            list.add("title");
            list.add("template");

            return list;
        }
    }

    /** Field attributes */
    public static DashboardFieldAttributes FieldAttributes=new DashboardFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public DashboardFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * area relation.
         *
         * @return the area bean relations attributes.
         */
        public Area.Relations area()
        {
            Area c = new Area();
            return c.new Relations(this.buildPath("area"));
        }

        /**
         * dashboardIndicators relation.
         *
         * @return the dashboardIndicators bean relations attributes.
         */
        public DashboardIndicator.Relations dashboardIndicators()
        {
            DashboardIndicator c = new DashboardIndicator();
            return c.new Relations(this.buildPath("dashboardIndicators"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the UNIQUEID path.
         *
         * @return the path
         */
        public String UNIQUEID()
        {
            return buildPath(Fields.UNIQUEID);
        }
        /**
         * the TITLE path.
         *
         * @return the path
         */
        public String TITLE()
        {
            return buildPath(Fields.TITLE);
        }
        /**
         * the TEMPLATE path.
         *
         * @return the path
         */
        public String TEMPLATE()
        {
            return buildPath(Fields.TEMPLATE);
        }
    }

    /** The dummy obj. */
    private static Dashboard dummyObj=new Dashboard();

    /**
     * Get Dashboard Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<Dashboard> getDataSet()
    {
        return new HibernateDataSet<Dashboard>(Dashboard.class, HibernateUtil.getSessionFactory("DIFRepository"),
            Dashboard.getPKFieldListAsString(), Dashboard.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<Dashboard> getDataSetInstance()
    {
        return new Dashboard().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("area".equalsIgnoreCase(attributeName))
            return area;
        if("uniqueId".equalsIgnoreCase(attributeName))
            return uniqueId;
        if("title".equalsIgnoreCase(attributeName))
            return title;
        if("template".equalsIgnoreCase(attributeName))
            return template;
        if("dashboardIndicators".equalsIgnoreCase(attributeName))
            return dashboardIndicators;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("area".equalsIgnoreCase(attributeName))
            area =(Area)attributeValue;
        if("uniqueId".equalsIgnoreCase(attributeName))
            uniqueId =(String)attributeValue;
        if("title".equalsIgnoreCase(attributeName))
            title =(String)attributeValue;
        if("template".equalsIgnoreCase(attributeName))
            template =(String)attributeValue;
        if("dashboardIndicators".equalsIgnoreCase(attributeName))
            dashboardIndicators =(Set<DashboardIndicator>)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** area private attribute */
    private Area area;

    /** uniqueId private attribute */
    private String uniqueId;

    /** title private attribute */
    private String title;

    /** template private attribute */
    private String template;

    /** dashboardIndicators private attribute */
    private Set<DashboardIndicator> dashboardIndicators = new HashSet<DashboardIndicator>(0);

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public Dashboard() {
    }

	/** 
	 * minimal constructor
	 *
     * @param area the area
     * @param uniqueId the uniqueId
     * @param title the title
     * @param template the template
    }
	 */
    public Dashboard(Area area, String uniqueId, String title, String template) {
        this.area = area;
        this.uniqueId = uniqueId;
        this.title = title;
        this.template = template;
    }

    /**
     * full constructor
	 *
     * @param area the area
     * @param uniqueId the uniqueId
     * @param title the title
     * @param template the template
     * @param dashboardIndicators the dashboardIndicators
     */
    public Dashboard(Area area, String uniqueId, String title, String template, Set<DashboardIndicator> dashboardIndicators) {
        this.area = area;
        this.uniqueId = uniqueId;
        this.title = title;
        this.template = template;
        this.dashboardIndicators = dashboardIndicators;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return Dashboard modified instance
     */
    public Dashboard setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * area getter method
     *
     * @return area method
     */
    public Area getArea() {
        return this.area;
    }
    
    /**       
     * area setter method
     *
     * @param area the area
     *
     * @return Dashboard modified instance
     */
    public Dashboard setArea(Area area) {
        this.area = area;
        
        return this;
    }
    /**       
     * uniqueId getter method
     *
     * @return uniqueId method
     */
    public String getUniqueId() {
        return this.uniqueId;
    }
    
    /**       
     * uniqueId setter method
     *
     * @param uniqueId the uniqueId
     *
     * @return Dashboard modified instance
     */
    public Dashboard setUniqueId(String uniqueId) {
        this.uniqueId = uniqueId;
        
        return this;
    }
    /**       
     * title getter method
     *
     * @return title method
     */
    public String getTitle() {
        return this.title;
    }
    
    /**       
     * title setter method
     *
     * @param title the title
     *
     * @return Dashboard modified instance
     */
    public Dashboard setTitle(String title) {
        this.title = title;
        
        return this;
    }
    /**       
     * template getter method
     *
     * @return template method
     */
    public String getTemplate() {
        return this.template;
    }
    
    /**       
     * template setter method
     *
     * @param template the template
     *
     * @return Dashboard modified instance
     */
    public Dashboard setTemplate(String template) {
        this.template = template;
        
        return this;
    }
    /**       
     * dashboardIndicators getter method
     *
     * @return dashboardIndicators method
     */
    public Set<DashboardIndicator> getDashboardIndicators() {
        return this.dashboardIndicators;
    }
    
    /**       
     * dashboardIndicators setter method
     *
     * @param dashboardIndicators the dashboardIndicators
     *
     * @return Dashboard modified instance
     */
    public Dashboard setDashboardIndicators(Set<DashboardIndicator> dashboardIndicators) {
        this.dashboardIndicators = dashboardIndicators;
        
        return this;
    }

    /**
     * Creates a String representation of the Dashboard object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("uniqueId").append("='").append(getUniqueId()).append("' ");			
        buffer.append("title").append("='").append(getTitle()).append("' ");			
        buffer.append("template").append("='").append(getTemplate()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the Dashboard object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(Dashboard other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("uniqueId".equalsIgnoreCase(attributeName))
        	this.uniqueId = attributeValue;

        if ("title".equalsIgnoreCase(attributeName))
        	this.title = attributeValue;

        if ("template".equalsIgnoreCase(attributeName))
        	this.template = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static Dashboard getProxy(Session session, Long id)
    {
        return(Dashboard)session.load(Dashboard.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static Dashboard getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Dashboard result = (Dashboard)session.load(Dashboard.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static Dashboard getInstance(Session session, Long id)
    {
        return(Dashboard)session.get(Dashboard.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static Dashboard getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Dashboard result = (Dashboard)session.get(Dashboard.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/Dashboard.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * Dashboard
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class Dashboard extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<Dashboard> {

    /**
    * Constant with the session factory ID
    */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /** Dashboard attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** uniqueId column */
        public static final String UNIQUEID ="uniqueId";
        /** title column */
        public static final String TITLE ="title";
        /** template column */
        public static final String TEMPLATE ="template";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("uniqueId");
            list.add("title");
            list.add("template");

            return list;
        }
    }

    /** Field attributes */
    public static DashboardFieldAttributes FieldAttributes=new DashboardFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public DashboardFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * area relation.
         *
         * @return the area bean relations attributes.
         */
        public Area.Relations area()
        {
            Area c = new Area();
            return c.new Relations(this.buildPath("area"));
        }

        /**
         * dashboardIndicators relation.
         *
         * @return the dashboardIndicators bean relations attributes.
         */
        public DashboardIndicator.Relations dashboardIndicators()
        {
            DashboardIndicator c = new DashboardIndicator();
            return c.new Relations(this.buildPath("dashboardIndicators"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the UNIQUEID path.
         *
         * @return the path
         */
        public String UNIQUEID()
        {
            return buildPath(Fields.UNIQUEID);
        }
        /**
         * the TITLE path.
         *
         * @return the path
         */
        public String TITLE()
        {
            return buildPath(Fields.TITLE);
        }
        /**
         * the TEMPLATE path.
         *
         * @return the path
         */
        public String TEMPLATE()
        {
            return buildPath(Fields.TEMPLATE);
        }
    }

    /** The dummy obj. */
    private static Dashboard dummyObj=new Dashboard();

    /**
     * Get Dashboard Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<Dashboard> getDataSet()
    {
        return getDataSetInstance();
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<Dashboard> getDataSetInstance()
    {
        return new HibernateDataSet<Dashboard>(Dashboard.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
            Dashboard.getPKFieldListAsString(), Dashboard.FieldAttributes);
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("area".equalsIgnoreCase(attributeName))
            return area;
        if("uniqueId".equalsIgnoreCase(attributeName))
            return uniqueId;
        if("title".equalsIgnoreCase(attributeName))
            return title;
        if("template".equalsIgnoreCase(attributeName))
            return template;
        if("dashboardIndicators".equalsIgnoreCase(attributeName))
            return dashboardIndicators;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("area".equalsIgnoreCase(attributeName))
            area =(Area)attributeValue;
        if("uniqueId".equalsIgnoreCase(attributeName))
            uniqueId =(String)attributeValue;
        if("title".equalsIgnoreCase(attributeName))
            title =(String)attributeValue;
        if("template".equalsIgnoreCase(attributeName))
            template =(String)attributeValue;
        if("dashboardIndicators".equalsIgnoreCase(attributeName))
            dashboardIndicators =(Set<DashboardIndicator>)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** area private attribute */
    private Area area;

    /** uniqueId private attribute */
    private String uniqueId;

    /** title private attribute */
    private String title;

    /** template private attribute */
    private String template;

    /** dashboardIndicators private attribute */
    private Set<DashboardIndicator> dashboardIndicators = new HashSet<DashboardIndicator>(0);

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * Gets description field.
     *
     * @return the description field
     */
    @Override
    public String getDescriptionField()
    {
        return FieldAttributes.getDescriptionField();
    }

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    @Override
    public List<String> getPKFields()
    {
        return getPKFieldList();
    }

    /**
     * Is composite PK.
     *
     * @return the boolean
     */
    @Override
    public boolean isCompositePK()
    {
        return this.getPKFieldList().size() > 1;
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {
        if (attributeName.contains("."))
        {
            return this.getAttributeAsStringParseBeanPath(attributeName);
        }
        else
        {
            Object value = getAttribute(attributeName);

            if (value == null)
                return "";
            else {
                return value.toString().trim();
            }
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public Dashboard() {
    }

	/** 
	 * minimal constructor
	 *
     * @param area the area
     * @param uniqueId the uniqueId
     * @param title the title
     * @param template the template
    }
	 */
    public Dashboard(Area area, String uniqueId, String title, String template) {
        this.area = area;
        this.uniqueId = uniqueId;
        this.title = title;
        this.template = template;
    }

    /**
     * full constructor
	 *
     * @param area the area
     * @param uniqueId the uniqueId
     * @param title the title
     * @param template the template
     * @param dashboardIndicators the dashboardIndicators
     */
    public Dashboard(Area area, String uniqueId, String title, String template, Set<DashboardIndicator> dashboardIndicators) {
        this.area = area;
        this.uniqueId = uniqueId;
        this.title = title;
        this.template = template;
        this.dashboardIndicators = dashboardIndicators;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return Dashboard modified instance
     */
    public Dashboard setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * area getter method
     *
     * @return area method
     */
    public Area getArea() {
        return this.area;
    }
    
    /**       
     * area setter method
     *
     * @param area the area
     *
     * @return Dashboard modified instance
     */
    public Dashboard setArea(Area area) {
        this.area = area;
        
        return this;
    }
    /**       
     * uniqueId getter method
     *
     * @return uniqueId method
     */
    public String getUniqueId() {
        return this.uniqueId;
    }
    
    /**       
     * uniqueId setter method
     *
     * @param uniqueId the uniqueId
     *
     * @return Dashboard modified instance
     */
    public Dashboard setUniqueId(String uniqueId) {
        this.uniqueId = uniqueId;
        
        return this;
    }
    /**       
     * title getter method
     *
     * @return title method
     */
    public String getTitle() {
        return this.title;
    }
    
    /**       
     * title setter method
     *
     * @param title the title
     *
     * @return Dashboard modified instance
     */
    public Dashboard setTitle(String title) {
        this.title = title;
        
        return this;
    }
    /**       
     * template getter method
     *
     * @return template method
     */
    public String getTemplate() {
        return this.template;
    }
    
    /**       
     * template setter method
     *
     * @param template the template
     *
     * @return Dashboard modified instance
     */
    public Dashboard setTemplate(String template) {
        this.template = template;
        
        return this;
    }
    /**       
     * dashboardIndicators getter method
     *
     * @return dashboardIndicators method
     */
    public Set<DashboardIndicator> getDashboardIndicators() {
        return this.dashboardIndicators;
    }
    
    /**       
     * dashboardIndicators setter method
     *
     * @param dashboardIndicators the dashboardIndicators
     *
     * @return Dashboard modified instance
     */
    public Dashboard setDashboardIndicators(Set<DashboardIndicator> dashboardIndicators) {
        this.dashboardIndicators = dashboardIndicators;
        
        return this;
    }

    /**
     * area id getter method
     *
     * @return area id method
     */
    public Long getAreaId() {
        if (this.area == null)
            return null;
        else
            return this.area.getId();
    }

    /**
     * Area proxy setter method from id.
     *
     * @return Dashboard modified instance
     */
    public Dashboard setAreaProxyFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.area = null;
        else
            this.area = Area.getProxy(id);

        return this;
    }

    /**
     * Area instance setter method from id.
     *
     * @return Dashboard modified instance
     */
    public Dashboard setAreaInstanceFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.area = null;
        else
            this.area = Area.getInstance(id);

        return this;
    }

    /**
     * Creates a String representation of the Dashboard object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("uniqueId").append("='").append(getUniqueId()).append("' ");			
        buffer.append("title").append("='").append(getTitle()).append("' ");			
        buffer.append("template").append("='").append(getTemplate()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the Dashboard object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(Dashboard other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("uniqueId".equalsIgnoreCase(attributeName))
        	this.uniqueId = attributeValue;

        if ("title".equalsIgnoreCase(attributeName))
        	this.title = attributeValue;

        if ("template".equalsIgnoreCase(attributeName))
        	this.template = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static Dashboard getProxy(Session session, Long id)
    {
        return(Dashboard)session.load(Dashboard.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static Dashboard getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Dashboard result = (Dashboard)session.load(Dashboard.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static Dashboard getInstanceForSession(Session session, Long id)
    {
        return(Dashboard)session.get(Dashboard.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static Dashboard getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Dashboard result = (Dashboard)session.get(Dashboard.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
